<?php
/**
 * Payment Method abstract class
 *
 * $Horde: payment/lib/Payment.php,v 1.15 2006/03/07 18:17:34 slusarz Exp $
 *
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Duck <duck@obala.net>
 * @package Horde_Payment
 */
class Payment_Method {

    /**
     * Hash containing method parameters.
     *
     * @var array
     */
    protected $params = array();

    /**
    * Tell us if the method needs an add additional data to be supplied
    **/
    function hasLocalForm()
    {
        return false;
    }

    /**
    * Tell us if the processing is done on remote server.
    **/
    function hasRemoteValidation()
    {
        return false;
    }

    /**
    * If true afterProcessMessage() method will be called
    * to outpout additonal content after paymant status is changed
    **/
    function hasAfterProcessMessage()
    {
        return false;
    }

    /**
    * The url to redirect the user to.
    *
    * @param array $data Array of payment data
    **/
    function getValidationUrl($data)
    {
        return '';
    }

    /**
    * Returns the payment method human name
    **/
    function getName()
    {
        return $this->params['name'];
    }

    /**
    * Call the payment method processing mechanism.
    *
    * @return payment status
    **/
    function process()
    {
        return PEAR::raiseError(_("Not supported."));
    }

    /**
     * Attempts to return a concrete Payment_Method instance based on $driver.
     *
     * @param string $driver  The type of the concrete Payment_Driver subclass
     *                        to return.  The class name is based on the
     *                        storage driver ($driver).  The code is
     *                        dynamically included.
     *
     * @return Payment_Driver  The newly created concrete Payment_Driver
     *                          instance, or false on an error.
     */
    function factory($driver)
    {
        $class = 'Payment_Method_' . $driver;
        if (!class_exists($class)) {
            include dirname(__FILE__) . '/Methods/' . $driver . '/' . $driver . '.php';
        }
        if (class_exists($class)) {
            return new $class();
        } else {
            return PEAR::raiseError(sprintf(_("Payment Method \"%s\" do not exists."), $driver));
        }
    }

}
