<?php
/**
 * Proforma bill
 *
 * $Horde: payment/lib/Payment.php,v 1.15 2006/03/07 18:17:34 slusarz Exp $
 *
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Duck <duck@obala.net>
 * @package Horde_Payment
 */
class Payment_Method_Proforma extends Payment_Method {

    /**
    * Creator
    */
    function Payment_Method_Proforma()
    {
        require dirname(__FILE__) . '/info.php';
        $this->params = $method_config;
    }

    /**
    * Call the payment method processing mechanism.
    **/
    function process()
    {
        return true;
    }

    /**
    * If the method needs an add additional data to be supplied
    **/
    function hasLocalForm()
    {
        return true;
    }

    /**
    * Return an array to fill the payment form with
    **/
    function fillFormVariables(&$form)
    {
        $form->addVariable(_("First name: "), 'first_name', 'text', true);
        $form->addVariable(_("Last name: "), 'last_name', 'text', true);
        $form->addVariable(_("Address: "), 'address', 'text', true);
        $form->addVariable(_("Postal code: "), 'zip', 'int', true);
        $form->addVariable(_("Town: "), 'town', 'text', true);
        $form->addVariable(_("State: "), 'state', 'text', false);

        if (empty($this->params['countries'])) {

            $form->addVariable(_("Country: "), 'country', 'enum', true, false, null, array(NLS::getCountryISO(), true));

        } else {

            $nls_countries = NLS::getCountryISO();
            $countries = array();
            foreach ($this->params['countries'] as $country) {
                $countries[$country] = $nls_countries[$country];
            }

            $desc = _("This payment method is available only for customers or deliveries to the listing countries. If your country is not listed, please use another payment method.");
            $form->addVariable(_("Country: "), 'country', 'enum', true, false, $desc, array($countries, true));
        }
    }

    /**
    * If true afterProcessMessage() method will be called
    * to outpout additonal content after paymant status is changed
    **/
    function hasAfterProcessMessage()
    {
        return true;
    }

    /**
    * Constract after process content
    **/
    function afterProcessMessage($payment_data, $status)
    {
        require PAYMENT_TEMPLATES . '/methods/Proforma/bill.inc';
    }
}
