<?php
/**
**/
define('PAYMENT_STATUS_PENDING', 2);
define('PAYMENT_STATUS_REVOKED', 4);
define('PAYMENT_STATUS_SUCCESSFUL', 6);

/**
 * Horde_Payment Base Class.
 *
 * $Horde: payment/lib/Payment.php,v 1.15 2006/03/07 18:17:34 slusarz Exp $
 *
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Duck <duck@obala.net>
 * @package Horde_Payment
 */
class Payment {

    /**
     * Retruns status name
     *
     * @param intiger $status Status to change the payment to
     * @param string  $id     Paymant id to the one to change the status to
     */
    function getStatusName($status)
    {
        switch ($status) {
        case PAYMENT_STATUS_PENDING:
            return _("Pending");

        case PAYMENT_STATUS_REVOKED:
            return _("Revoked");

        case PAYMENT_STATUS_SUCCESSFUL:
            return _("Successful");

        default:
            return _("Error");
        }
    }

    /**
     * Update the status and call back the selling api
     *
     * @param intiger $status Status to change the payment to
     * @param string  $id     Paymant id to the one to change the status to
     *
     * @return mixed True if success, PEAR_Error on failure
     */
    function changeStatus($status, $id)
    {
        global $registry, $payment;

        // Get payment data
        $payment_data = $payment->getAuthorization($id);
        if (is_a($payment_data, 'PEAR_Error')) {
            return $payment_data;
        }

        // Update DB 
        $result = $payment->updateAuthorization($id, array('status' => $status));
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }

        // Callback the selling api
        $provides = $registry->get('provides', $payment_data['module_name']);
        if ($registry->hasMethod($provides . '/authorizationResponse')) {
            $params = array('status_id' => $status,
                            'status_name' => Payment::getStatusName($status));
            return $registry->call($provides . '/authorizationResponse', array($payment_data['module_id'], $params));
        }

        return true;
    }

    /**
     * Retruns formatted price
     *
     * @param float $price      The price value to format
     *
     * @return string  The locale formatted price string.
     */
    function formatPrice($price, $nosymbol = false)
    {
        require_once HORDE_BASE . '/incubator/Horde_Currencies/Currencies.php';

        $currencies = new Horde_CurrenciesMapper();
        $currency = $currencies->getDefault('data');

        if ($nosymbol) {
            $currency['p_sep_by_space'] = false;
            $currency['currency_symbol'] = '';
        }

        return Horde_Currencies::formatPrice($price, $currency);
    }

    /**
     * Fomates time accoring to user prefs
     *
     * @param int $timestamp message timestamp
     *
     * @return string $date fromatted date
     */
    function format_date($timestamp, $time = true)
    {
        if (intval($timestamp)<1000000000) {
            $timestamp = strtotime($timestamp);
        }

        $formatted = strftime($GLOBALS['prefs']->getValue('date_format'), $timestamp);
        if ($time) {
            $formatted .= ' ' . date($GLOBALS['prefs']->getValue('twentyFour') ? 'G:i' : 'g:ia', $timestamp);
        }
        
        return $formatted;
    }

    /**
     * Returns a new or the current CAPTCHA string.
     *
     * @param boolean $new  If true, a new CAPTCHA is created and returned.
     *                      The current, to-be-confirmed string otherwise.
     *
     * @return string  A CAPTCHA string.
     */
    function getCAPTCHA($new = false)
    {
        if ($new || empty($_SESSION['payment']['CAPTCHA'])) {
            $_SESSION['payment']['CAPTCHA'] = '';
            for ($i = 0; $i < 5; $i++) {
                $_SESSION['payment']['CAPTCHA'] .= chr(rand(65, 90));
            }
        }
        return $_SESSION['payment']['CAPTCHA'];
    }

    /**
     * Returns the list of the avaiable payment methods
     */
    function getMethods($app = null)
    {
        $dir = PAYMENT_BASE . '/lib/Methods/';

        if ($app) {
            require_once 'Horde/Array.php';
            $methods = Horde_Array::valuesToKeys($GLOBALS['payment']->getMethods($app));
        } else {
            if ($dh = opendir($dir)) {
                while (($file = readdir($dh)) !== false) {
                    if ($file != '..' && $file != '.') {
                        $methods[$file] = $file;
                    }
                } 
                closedir($dh);
            }
        }

        if (empty($methods)) {
            return PEAR::raiseError(_("No methods available."));
        }

        foreach ($methods as $method) {
            if (@include $dir . '/' . $method . '/info.php') {
                if (isset($method_config)) {
                    $methods[$method] = $method_config['name'];
                    if (isset($method_config['description'])) {
                        $methods[$method] .= ' (' . $method_config['description'] . ') ';    
                    }
                    unset($method_config);
                } else {
                    unset($methods[$method]);
                }
            } else {
                unset($methods[$method]);
            }
        }

        return $methods;
    }

    /**
     * Build Payment's list of menu items.
     */
    function getMenu($returnType = 'object')
    {
        global $conf, $registry, $browser, $print_link;

        require_once 'Horde/Menu.php';

        $menu = &new Menu(HORDE_MENU_MASK_ALL);
        $menu->add(Horde::applicationUrl('list.php'), _("List"), 'user.png', $registry->getImageDir('horde'));
        $menu->add(Horde::applicationUrl('matrix.php'), _("Matrix"), 'user.png', $registry->getImageDir('horde'));
        $menu->add(Horde::applicationUrl('process/enter.php'), _("Process"), 'user.png', $registry->getImageDir('horde'));

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}
