<?php
/**
 * Check id of the payment
 *
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('PAYMENT_BASE', dirname(__FILE__) . '/../');
require_once PAYMENT_BASE . '/lib/base.php';
require_once PAYMENT_BASE . '/lib/Forms/PaymentData.php';

// Try to get order data
$id = Util::getFormData('id', @$_SESSION['payment']['process_id']);
$payment_data = $payment->getAuthorization($id);
if (is_a($payment_data, 'PEAR_Error')) {
    $notification->push($payment_data->getMessage(), 'horde.error');
    header('Location: ' . Horde::applicationUrl('process/enter.php'));
    exit;
}

// Store order id in session
if (!isset($_SESSION['payment']) ||
    !isset($_SESSION['payment']['process_id']) || 
    $id != $_SESSION['payment']['process_id']) {
    $_SESSION['payment']['process_id'] = $id;
}

// Get methods
$methods = Payment::getMethods($payment_data['module_name']);
if (is_a($methods, 'PEAR_Error')) {
    $notification->push($methods->getMessage(), 'horde.error');
    header('Location: ' . Horde::applicationUrl('process/enter.php'));
    exit;
}

// If ony one avaiable method exits. Redirect the user to it.
if (sizeof($methods) == 11) {
    $_SESSION['payment']['process_step'] = 1;
    $payment->updateAuthorization($id, array('method' => key($methods)));
    header('Location: ' . Horde::applicationUrl('process/step1.php'));
    exit;
}

// Prepare form
$title = _("Select payment method"); 
$vars = Variables::getDefaultVariables();
$form = new Payment_Form_Data($vars, $title, $payment_data);

$form->setButtons(array(_("Revoke"), _("Proceed")));
$form->addVariable(_("Payment method"), 'method', 'radio', true, false, false, array($methods));

if (Auth::isAuthenticated()) {
    $form->addVariable(_("Set this payment as default?"), 'setdefault', 'boolean', false);
}

if ($form->validate($vars)) {

    $form->getInfo($vars, $info);
    
    // Redirect to revoke confirmation
    if (Util::getFormData('submitbutton') == _("Revoke")) {
        header('Location: ' . Horde::applicationUrl('process/revoke.php'));
        exit;
    }

    // Save default method
    if (Auth::isAuthenticated() && $info['setdefault']) {
        $prefs->getValue('default_payment', $info['method']);
    }

    // Start payment process
    $_SESSION['payment']['process_step'] = 1;
    $payment->updateAuthorization($id, array('method' => $info['method']));

    header('Location: ' . Horde::applicationUrl('process/step1.php'));
    exit;

} elseif (!$form->isSubmitted()) {

    $vars->set('method', $prefs->getValue('default_payment'));
}

require PAYMENT_TEMPLATES . '/common-header.inc';
require PAYMENT_TEMPLATES . '/process/header.inc';

$form->renderActive(new Horde_Form_Renderer(), $vars, Horde::applicationUrl('process/index.php'), 'post');

require $registry->get('templates', 'horde') . '/common-footer.inc';
